"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildCodeGenFunctions = void 0;
const _generators_1 = require("../generators");
const _models_1 = require("../models");
const _store_1 = require("../store");
const _templates_1 = require("../templates");
const ora_1 = __importDefault(require("ora"));
const MessageMode = {
    [_models_1.CodeGenType.METHODS]: '🧬 queries, mutations and subscriptions',
    [_models_1.CodeGenType.REACT_HOOKS]: '⚛️  React hooks',
    [_models_1.CodeGenType.VUE_HOOKS]: '🅅  Vue 3 Hooks',
    [_models_1.CodeGenType.TEMPLATE]: 'GraphQL templates',
};
function buildCodeGenFunctions(mode) {
    const message = MessageMode[mode];
    const oraMethods = ora_1.default(`Generating ${message}...`).start();
    try {
        const [queries, mutations, subscriptions] = _store_1.SchemaStore.schemaFunctions;
        const generatedQueries = queries.map((field) => _generators_1.generateFunction({ field, functionType: _models_1.MethodType.Query, mode }));
        const generatedMutations = mutations.map((field) => _generators_1.generateFunction({ field, functionType: _models_1.MethodType.Mutation, mode }));
        const generatedSubscriptions = subscriptions.map((field) => _generators_1.generateFunction({ field, functionType: _models_1.MethodType.Subscription, mode }));
        oraMethods.succeed(`${message} successfully generated`);
        const allFunctions = [...generatedQueries, ...generatedMutations, ...generatedSubscriptions];
        if (mode === _models_1.CodeGenType.REACT_HOOKS) {
            return _templates_1.withReactHooksTemplate(allFunctions);
        }
        else if (mode === _models_1.CodeGenType.VUE_HOOKS) {
            return _templates_1.withVueHooksTemplate(allFunctions);
        }
        else if (mode === _models_1.CodeGenType.METHODS) {
            return _templates_1.withFunctionsTemplate(generatedQueries, generatedMutations);
        }
        else {
            return _templates_1.withDefinitionsTemplate(allFunctions);
        }
    }
    catch (e) {
        console.log(e);
        oraMethods.fail(`${message} generation failed`);
        return e;
    }
}
exports.buildCodeGenFunctions = buildCodeGenFunctions;
