"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateQueryFunction = exports.generateTemplateQuery = void 0;
const _store_1 = require("../store");
function generateTemplateQuery({ field, functionType, innerFragment, defaultFragmentName, }) {
    const { GQLArgs, GQLVariables } = _store_1.SchemaStore.getFunctionFieldArgs(field);
    const { isScalar } = _store_1.SchemaStore.getFieldProps(field);
    const hasArgs = field.args.length > 0;
    const methodName = field.name;
    const typeNameLower = functionType;
    if (isScalar) {
        return `gql\`
      ${typeNameLower} ${methodName} ${hasArgs ? `(${GQLVariables.join(',')})` : ''} {
        ${methodName}${hasArgs ? `(${GQLArgs.join(',')})` : ''}
      }\``;
    }
    else if (!defaultFragmentName) {
        return `gql\`
      ${typeNameLower} ${methodName} ${hasArgs ? `(${GQLVariables.join(',')})` : ''} {
        ${methodName}${hasArgs ? `(${GQLArgs.join(',')})` : ''} {
          ${innerFragment}
        }
      } \${isFragment ? fragment : ''}
      \``;
    }
    else {
        return `gql\`
      ${typeNameLower} ${methodName} ${hasArgs ? `(${GQLVariables.join(',')})` : ''} {
        ${methodName}${hasArgs ? `(${GQLArgs.join(',')})` : ''} {
          ...${defaultFragmentName}
        }
      } \${${defaultFragmentName}}
      \``;
    }
}
exports.generateTemplateQuery = generateTemplateQuery;
function generateQueryFunction({ field, functionType, innerFragment, }) {
    const { isScalar } = _store_1.SchemaStore.getFieldProps(field);
    const Query = generateTemplateQuery({ field, innerFragment, functionType });
    if (isScalar) {
        return `export const ${field.name}GQLNode = (): DocumentNode =>  {
      return ${Query};
    }`;
    }
    else {
        return `export const ${field.name}GQLNode = (fragment: string | DocumentNode): DocumentNode => {
      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);
      return ${Query};
    }`;
    }
}
exports.generateQueryFunction = generateQueryFunction;
