"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = exports.getConfigParams = void 0;
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const inquirer_1 = __importDefault(require("inquirer"));
const figlet_1 = __importDefault(require("figlet"));
const templates_1 = require("../templates");
require('dotenv').config();
function getConfigParams(generate) {
    const stageEnv = !generate ? 'development' : generate;
    require('custom-env').env(stageEnv);
    const configPath = path_1.default.resolve(process.cwd(), '.sgtsrc.js');
    if (fs_1.default.existsSync(configPath)) {
        return require(path_1.default.resolve(process.cwd(), '.sgtsrc.js'));
    }
    return null;
}
exports.getConfigParams = getConfigParams;
const createConfig = async () => {
    try {
        console.log(chalk_1.default.magenta(figlet_1.default.textSync('SGTS', {
            horizontalLayout: 'full',
        })));
        const sourceType = await inquirer_1.default.prompt([
            {
                type: 'list',
                name: 'type',
                message: 'Where does your GraphQL schema comes from?',
                choices: [
                    {
                        name: 'From an http endpoint',
                        value: 'endpoint',
                    },
                    {
                        name: 'From a JSON file',
                        value: 'json',
                    },
                ],
            },
        ]);
        const sourceValue = await inquirer_1.default.prompt([
            {
                type: 'input',
                name: 'source',
                message: sourceType.type === 'endpoint'
                    ? "What's the url of your GraphQL api endpoint?"
                    : "What's the absolute path to your GraphQL JSON schema?",
            },
        ]);
        const outputPath = await inquirer_1.default.prompt([
            {
                type: 'input',
                name: 'ouput',
                message: 'Where do you want to save your generated file?',
                default: './__generated.ts',
            },
        ]);
        const codeGen = await inquirer_1.default.prompt([
            {
                type: 'checkbox',
                name: 'codeGens',
                message: 'What do you want to generate?',
                choices: [
                    new inquirer_1.default.Separator('------'),
                    {
                        name: 'Typescript definitions',
                        checked: true,
                        disabled: 'Sgts will always generate definitions by default',
                    },
                    new inquirer_1.default.Separator('------'),
                    {
                        name: 'Vanilla es6 helpers functions',
                        value: 'codegenFunctions',
                    },
                    {
                        name: 'Apollo React Hooks',
                        value: 'codegenReactHooks',
                    },
                    {
                        name: 'Vue Apollo Hooks',
                        value: 'codegenVueHooks',
                    },
                    {
                        name: 'Only GraphQL string templates',
                        value: 'codegenTemplates',
                    },
                ],
            },
        ]);
        const configPath = path_1.default.resolve(process.cwd(), '.sgtsrc.js');
        if (fs_1.default.existsSync(configPath)) {
            const replace = await inquirer_1.default.prompt([
                {
                    type: 'confirm',
                    name: 'delete',
                    message: 'A config file already exists in this folder, do you want to replace it?',
                },
            ]);
            if (!replace.delete) {
                console.log('Ok bye!');
                return;
            }
        }
        const codeGenDisplay = codeGen.codeGens.map((m) => `${m}: true,`);
        const configValue = `module.exports = {
    ${sourceType.type}: "${sourceValue.source}",
    output: "${outputPath.ouput}",
    ${codeGenDisplay.join('\n  ')}
}
    `;
        await fs_1.default.writeFileSync(configPath, templates_1.configTemplate(configValue));
        console.log(chalk_1.default.green(`Configuration file created at ${chalk_1.default.bold(configPath)}`));
    }
    catch (e) {
        return Promise.reject(e);
    }
};
exports.createConfig = createConfig;
