"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sgtsGenerate = void 0;
const chalk_1 = __importDefault(require("chalk"));
const utilities_1 = require("./utilities");
const save_1 = require("./save");
const store_1 = require("./store");
async function sgtsGenerate({ endpoint, json, output, customScalars, header, jsMode, download, ...rest }) {
    console.log(`\n Sgts v${require('../package.json').version}`);
    try {
        const introspectionSchema = await utilities_1.retrieveIntrospectionSchema({
            endpoint,
            header,
            json,
            download,
        });
        if (introspectionSchema) {
            store_1.SchemaStore.setSchema(introspectionSchema);
            store_1.ParametersStore.setParamaters({
                scalars: customScalars,
                ...rest,
            });
            const generatedString = store_1.OutputStore.getRenderedFileString();
            return await save_1.saveFile(generatedString, output, jsMode);
        }
        else {
            console.warn(chalk_1.default.yellow('\n ⚠️ You need to either provite a source url or a path to your json schema file'));
        }
    }
    catch (e) {
        console.error(chalk_1.default.red(e));
        return Promise.reject(e);
    }
}
exports.sgtsGenerate = sgtsGenerate;
