#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const runtime_1 = require("./runtime");
const chalk_1 = __importDefault(require("chalk"));
const rc_1 = require("./rc");
const runSgtsCLI = () => {
    commander_1.program
        .version(require('../package.json').version)
        .option('-e, --endpoint <endpoint>', 'GraphQl Api endpoint')
        .option('-j, --json <json>', 'Json file of your GraphQL Api schema')
        .option('-o, --output <output>', 'Output path of your generated file')
        .option('--codegen-functions', 'Generate all your graphQL methods fully typed (Inspired by Prisma)')
        .option('--codegen-react-hooks', 'Generate useMutation and useQuery React hooks typed')
        .option('--codegen-vue-hooks', 'Generate useMutation and useQuery React hooks typed')
        .option('--codegen-templates', 'Add gql query strings to the generated output')
        .option('--gen-fragments', 'Auto-generates fragment and include them in queries')
        .option('--header <header>', 'Additional header option to fetch your schema from endpoint')
        .option('--customScalars <scalars>', 'Provide your custum scalars in format {"myScalar": "MyType"...}')
        .option('-p, --prefix <prefix>', 'Add prefix to all your types (ex: User becomes IUser with --suffix I)')
        .option('-s, --suffix <suffix>', 'Add suffix to all your types (ex: User becomes UserModel with --suffix Model)')
        .option('--compileToJs', 'Generate the methods in Js with declaration files instead of Ts')
        .option('-D, --download <download>', 'Specify the path to download the GraphQL introspection schema')
        .action(({ endpoint, json, output = './__generated.ts', customScalars, header, prefix, suffix, codegenFunctions, jsMode, codegenReactHooks, codegenVueHooks, codegenTemplates, download, genFragments, }) => {
        if (customScalars) {
            try {
                customScalars = JSON.parse(customScalars);
            }
            catch (e) {
                console.error(chalk_1.default.red('Invalid custom scalars format, expected {"myScalar": "MyType" ...}'));
                return;
            }
        }
        generateUsingConfig({
            endpoint,
            json,
            output,
            customScalars,
            header,
            prefix,
            suffix,
            codegenFunctions,
            jsMode,
            codegenReactHooks,
            codegenVueHooks,
            codegenTemplates,
            download,
            genFragments,
        });
    });
    commander_1.program
        .command('generate [generate]')
        .description("Generate using config file '.sgtsrc.js'")
        .action((value) => {
        const config = rc_1.getConfigParams(value);
        if (config) {
            generateUsingConfig(config);
        }
        else {
            rc_1.createConfig();
        }
    });
    commander_1.program
        .command('init')
        .description('Init your config file')
        .action(() => {
        rc_1.createConfig();
    });
    commander_1.program.parse(process.argv);
};
const generateUsingConfig = async (config) => {
    try {
        await runtime_1.sgtsGenerate(config);
    }
    catch (e) {
        console.error(chalk_1.default.red('💔 Generation failed'));
    }
};
runSgtsCLI();
