"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutputStore = void 0;
const _templates_1 = require("../templates");
const _builders_1 = require("../builders");
const parameters_store_1 = require("./parameters.store");
const _models_1 = require("../models");
const ora_1 = __importDefault(require("ora"));
class OutputConstructor {
    constructor() {
        this.signature = _templates_1.sharedTemplate;
        this.loader = ora_1.default('🔄 Transpiling GraphQL schema to Typescript interfaces');
    }
    getRenderedFileString() {
        this.loader.start();
        try {
            const { genFragments, codegenFunctions, codegenReactHooks, codegenTemplates, codegenVueHooks, } = parameters_store_1.ParametersStore;
            const IMPORTS = _templates_1.defineImports();
            const INTERFACES = _builders_1.buildSchemaTypes();
            const FUNCTION_ARGS = _builders_1.buildMethodsArgsTypes();
            let FRAGMENTS = [];
            let CODEGEN_FUNCTIONS = '';
            let CODEGEN_REACT_HOOKS = '';
            let CODEGEN_VUE_HOOKS = '';
            let CODEGEN_TEMPLATES = '';
            if (genFragments)
                FRAGMENTS = _builders_1.buildFragments();
            if (codegenFunctions)
                CODEGEN_FUNCTIONS = _builders_1.buildCodeGenFunctions(_models_1.CodeGenType.METHODS);
            if (codegenReactHooks)
                CODEGEN_REACT_HOOKS = _builders_1.buildCodeGenFunctions(_models_1.CodeGenType.REACT_HOOKS);
            if (codegenVueHooks)
                CODEGEN_VUE_HOOKS = _builders_1.buildCodeGenFunctions(_models_1.CodeGenType.VUE_HOOKS);
            if (codegenTemplates)
                CODEGEN_TEMPLATES = _builders_1.buildCodeGenFunctions(_models_1.CodeGenType.TEMPLATE);
            this.loader.succeed(`📝 Schema transpiled to Typescript`);
            return `
      ${this.signature}
      ${IMPORTS}
      ${INTERFACES.join('\n')}
      ${FUNCTION_ARGS.join('\n')}
      ${FRAGMENTS.join('\n')}
      ${CODEGEN_FUNCTIONS}
      ${CODEGEN_REACT_HOOKS}
      ${CODEGEN_VUE_HOOKS}
      ${CODEGEN_TEMPLATES}
    `;
        }
        catch (e) {
            this.loader.fail('Transpiling failed');
            return e;
        }
    }
}
exports.OutputStore = new OutputConstructor();
