"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaStore = void 0;
const _generators_1 = require("../generators");
const _models_1 = require("../models");
const parameters_store_1 = require("./parameters.store");
const regexFilter = (field) => !/(^_{1,2})|Query|Mutation|Subscription/.test(field.name);
class SchemaConstructor {
    get schemaTypes() {
        var _a;
        return (_a = this.schema) === null || _a === void 0 ? void 0 : _a.__schema.types.filter(regexFilter);
    }
    get schemaObjectTypes() {
        return this.schema.__schema.types.filter((type) => type.kind === _models_1.TypeKind.OBJECT);
    }
    get schemaFunctions() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        const _schema = this.schema.__schema;
        const QueryType = _schema.queryType.name;
        const MutationType = (_b = (_a = _schema.mutationType) === null || _a === void 0 ? void 0 : _a.name) !== null && _b !== void 0 ? _b : null;
        const SubscriptionType = (_d = (_c = _schema.subscriptionType) === null || _c === void 0 ? void 0 : _c.name) !== null && _d !== void 0 ? _d : null;
        let listQueries = (_f = (_e = _schema.types.find((type) => type.name === QueryType)) === null || _e === void 0 ? void 0 : _e.fields) !== null && _f !== void 0 ? _f : [];
        let listMutations = [];
        let listSubscription = [];
        if (MutationType) {
            listMutations = (_h = (_g = _schema.types.find((type) => type.name === MutationType)) === null || _g === void 0 ? void 0 : _g.fields) !== null && _h !== void 0 ? _h : [];
        }
        if (SubscriptionType) {
            listSubscription = (_k = (_j = _schema.types.find((type) => type.name === SubscriptionType)) === null || _j === void 0 ? void 0 : _j.fields) !== null && _k !== void 0 ? _k : [];
        }
        return [
            listQueries.filter(regexFilter),
            listMutations.filter(regexFilter),
            listSubscription.filter(regexFilter),
        ];
    }
    findType(typeName) {
        return this.schemaTypes.find((type) => type.name === typeName);
    }
    isTypeConnection(typeName) {
        const type = this.findType(typeName);
        if (type && type.fields) {
            return type.fields.map(this.getFieldProps).some(({ isConnection }) => isConnection);
        }
        return false;
    }
    areFieldArgsAllOptional(field) {
        return field.args.map(this.getFieldProps).every(({ isRequired }) => !isRequired);
    }
    getFunctionFieldArgs(field) {
        const { prefix, suffix } = parameters_store_1.ParametersStore;
        const { GQLVariables, GQLArgs } = field.args.reduce((acc, arg) => {
            const argName = arg.name;
            const type = _generators_1.generateQGLArg(arg);
            acc.GQLVariables.push(`$${argName}: ${type}`);
            acc.GQLArgs.push(`${argName}: $${argName}`);
            return acc;
        }, {
            GQLVariables: [],
            GQLArgs: [],
        });
        let functionArgsTypeName = '';
        if (field.args.length) {
            const parsedSuffix = (suffix ? suffix : '') + 'Args';
            functionArgsTypeName = `${prefix ? prefix : ''}${field.name}${parsedSuffix}`;
        }
        return {
            GQLArgs,
            GQLVariables,
            functionArgsTypeName,
        };
    }
    getFieldProps(field) {
        let propertyName = field.name;
        let isRequired = false;
        let isArray = false;
        let isArrayRequired = false;
        let isConnection = false;
        let isScalar = false;
        let isEnum = false;
        let typeName = '';
        if (propertyName === 'edges')
            isConnection = true;
        function getOfTypeProps(type) {
            if (type.kind === _models_1.TypeKind.NON_NULL) {
                if (isArray)
                    isArrayRequired = true;
                else
                    isRequired = true;
            }
            if (type.kind === _models_1.TypeKind.LIST)
                isArray = true;
            if (type.ofType)
                return getOfTypeProps(type.ofType);
            else {
                if (type.kind === _models_1.TypeKind.SCALAR)
                    isScalar = true;
                else if (type.kind === _models_1.TypeKind.ENUM)
                    isEnum = true;
                typeName = type.name;
            }
            return null;
        }
        getOfTypeProps(field.type);
        return {
            isRequired,
            isArray,
            isArrayRequired,
            isConnection,
            isScalar,
            typeName,
            isEnum,
        };
    }
    setSchema(schema) {
        this.schema = schema;
    }
}
exports.SchemaStore = new SchemaConstructor();
